#' @name AndradeEx4.9
#' @title Ocorrências de Plantas \emph{Primula Sinensis} Selvagens
#' @description Uma certa região florestal foi dividida em 109 parcelas
#'     de mesma área (quadrados) para se estudar a distribuição das
#'     plantas \emph{Primula sinensis} selvagens na região. A priori,
#'     supõe-se que plantas dessa espécie distribuem-se aleatoriamente.
#' @format Um \code{data.frame} com 10 observações e 2 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{nplantas}}{Número de plantas na parcela.}
#'
#' \item{\code{nparc}}{Número de parcelas com \code{nplantas} plantas.}
#'
#' }
#' @keywords contingência*
#' @source Andrade, D. F., Ogliari, P. J. (2010). Estatística para as
#'     ciências agrárias e biológicas com noções de experimentação (2nd
#'     ed.). Florianópolis, SC. Editora da UFSC. (Capítulo 4, Exercício
#'     9, pág. 238)
#' @examples
#'
#' data(AndradeEx4.9)
#' str(AndradeEx4.9)
#'
#' #' # Média do número de plantas doentes por parcela
#' with(AndradeEx4.9, weighted.mean(nplantas, nparc))
#'
#' # Distribuição de frequências
#' txt <- barplot(AndradeEx4.9$nparc,
#'                col = "darkturquoise",
#'                names.arg = AndradeEx4.9$nplantas,
#'                xlab = "Número de Plantas no Quadrado",
#'                ylab = "Número de Quadrados")
#' text(x = txt, y = AndradeEx4.9$nparc)
#'
NULL
