#' @name BracarensePg177
#' @title População Recenseada e Estimada em 2007
#' @description População recenseada e estimada, segundo as unidades da
#'     federação (2007).
#' @format Um \code{data.frame} com 27 linhas e 3 colunas em que:
#'
#' \describe{
#'
#' \item{\code{Reg}}{Região a qual pertence o estado.}
#'
#' \item{\code{Est}}{Estado do Brasil.}
#'
#' \item{\code{Pop}}{População do Estado.}
#'
#' }
#' @keywords estatística básica
#' @source BRACARENSE (2009), exemplo página 177.
#' @examples
#'
#' data(BracarensePg177)
#' str(BracarensePg177)
#'
#' dados  <- aggregate(Pop ~ Reg,
#'                     data = BracarensePg177,
#'                     FUN = sum)
#' dados
#'
#' barplot(dados$Pop/sum(dados$Pop),
#'         names.arg = dados$Reg,
#'         col = rainbow(5),
#'         main = "Porcentagem da População Brasileira por Região")
#'
#' library(lattice)
#' library(latticeExtra)
#'
#' # Gráfico de pareto da distribuição da população.
#' barchart(Pop/sum(Pop) ~ reorder(Est, -Pop),
#'          data = BracarensePg177,
#'          ylim = c(0, NA),
#'          scales = list(x = list(rot = 90)),
#'          xlab = "Estados brasileiros",
#'          ylab = "Poporção da população total") +
#'     layer(panel.text(x = x,
#'                      y = y,
#'                      labels = sprintf("%0.2f", y),
#'                      cex = 0.8,
#'                      adj = c(-0.25, 0.5),
#'                      srt = 90))
#'
NULL
