#' @name NetoTb2.4
#' @title Comparação de Titulação de Viangre por 2 Químicos
#' @description Dois químicos, Arrhenius e Berzelius, foram encarregados
#'     de analisar lotes de vinagre de 5 diferentes fabricantes. O
#'     experimento contém um único fator com dois níveis (os químicos) e
#'     uma resposta (o teor de acído acético, em \%). As medidas são
#'     pareadas, ou seja, os dois quimícos avaliam cada um dos vinagres
#'     gerando, para cada vinagre, um par de valores da resposta.
#' @format Um \code{data.frame} com 5 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{Arr}}{Teores de ácido acético determinados pelo Químico
#'     Arrhenius.}
#'
#' \item{\code{Ber}}{Teores de ácido acético determinados pelo Químico
#'     Berzelius.}
#'
#' \item{\code{d}}{Diferença de concentação obtida entre os químicos
#'     para a amostra de vinagre do mesmo fabricante.}
#'
#' }
#' @keywords pareada
#' @source NETO et al. (2010), Tabela 2.4, pág. 79.
#' @examples
#'
#' library(lattice)
#' library(latticeExtra)
#'
#' data(NetoTb2.4)
#' str(NetoTb2.4)
#'
#' dotplot(1:length(d) ~ Arr + Ber,
#'         data = NetoTb2.4,
#'         auto.key = TRUE,
#'         xlab = "Teor de ácido acético (%)",
#'         ylab = "Fabricantes")
#'
#' xyplot(Arr ~ Ber,
#'        data = NetoTb2.4,
#'        aspect = "iso",
#'        grid = TRUE,
#'        xlab = "Berzelius",
#'        ylab = "Arrhenius") +
#'     layer(panel.abline(a = 0, b = 1, lty = 2))
#'
NULL
