#' @name NetoTb2A.1
#' @title Tempo de Casa ao Trabalho em 3 Percursos
#' @description Foi cronometrado o tempo transcorrido desde o momento em
#'    que o ônibus passa por uma ponte no trajeto até a hora que o
#'    pesquisador chega à seu destino final. Os dados possem registros
#'     do dia da semana e do percurso que foi feito.
#' @format Um \code{data.frame} com 32 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{sai}}{Variável que indica o horário de saída do
#'     pesquisador rumo ao destino final.}
#'
#' \item{dia}{Fator de 5 níveis referentes aos dias da semana em que o
#'    pesquisador realizou o trajeto.}
#'
#' \item{perc}{Fator de 3 níveis referentes ao percurso (trajeto)
#'     realizado.}
#'
#' \item{tem}{Tempo até chegar os destino final, em minutos.}
#'
#' }
#' @keywords RM
#' @source NETO et al. (2010), Tabela 2A.1, pág. 86.
#' @examples
#'
#' data(NetoTb2A.1)
#' str(NetoTb2A.1)
#'
#' library(lattice)
#'
#' NetoTb2A.1$hora <- as.POSIXct(NetoTb2A.1$sai, format = "%H:%M")
#' NetoTb2A.1$hora <- as.numeric(difftime(NetoTb2A.1$hora,
#'                                        min(NetoTb2A.1$hora),
#'                                        units = "mins"))
#'
#' addmargins(xtabs(~dia + perc, data = NetoTb2A.1))
#'
#' xyplot(tem ~ hora | perc,
#'        type = "p",
#'        groups = dia,
#'        auto.key = TRUE,
#'        par.settings = list(superpose.symbol = list(pch = 19)),
#'        data = NetoTb2A.1,
#'        xlab = "Ensaio",
#'        ylab = "Tempo",
#'        main = "Tempo de Viagem")
#'
NULL
