#' @name NetoTb3.6
#' @title Influência de Quatro Fatores no Rendimento de uma Reação
#' @description Resultados de um experimento fatorial \eqn{2^4} que
#'     estudou o efeito de quatro fatores no rendimento de uma reação
#'     química.
#' @format Um \code{data.frame} com 16 observações e 5 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{f1}}{Temperatura (40 e 60\eqn{^\circ}C).}
#'
#' \item{\code{f2}}{Tipo de catalisador (A e B).}
#'
#' \item{\code{f3}}{Concentração (1 e 1.5 M).}
#'
#' \item{\code{f4}}{Acidez (pH 7 e 6).}
#'
#' \item{rend}{Rendimento de uma reação.}
#'
#' }
#' @keywords FAT2K
#' @source NETO et al. (2010), Tabela 3.6, pág. 130.
#' @examples
#'
#' library(lattice)
#'
#' data(NetoTb3.6)
#' str(NetoTb3.6)
#'
#' xyplot(res ~ f1 | f2,
#'        groups = interaction(f3, f4, sep = ":"),
#'        data = NetoTb3.6,
#'        type = c("p", "a"),
#'        auto.key = TRUE)
#'
NULL
