#' @name NetoTb3A.2
#' @title Voltametria Cíclica do Azul de Metileno
#' @description As propriedades eletroquímicas do azul de metileno foram
#'     investigadas com o objetivo de determinar as condições
#'     experimentais, controlando três fatores, que minimizam a
#'     diferença de voltagem (delta).
#' @format Um \code{data.frame} com 8 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{f1}}{Fator 1, concentração (0.1 e 0.5), em mol L\eqn{^{-1}}.}
#'
#' \item{\code{f2}}{Fator 2, pH (4 e 7).}
#'
#' \item{\code{f3}}{Fator 3, tipo de sílica modificada (STM e STPM).}
#'
#' \item{\code{delta}}{Diferença de voltagem (mV).}
#'
#' }
#' @keywords FAT2K
#' @source NETO et al. (2010), Tabela 3A.2, pág. 147.
#' @examples
#'
#' data(NetoTb3A.2)
#' str(NetoTb3A.2)
#'
#' par(mfrow = c(1, 3))
#'
#' with(NetoTb3A.2,
#'      interaction.plot(f1, f2, delta,
#'                       xlab = "Concentração",
#'                       ylab = "Média de Delta",
#'                       main = "Concentração x PH",
#'                       col = "green"))
#'
#' with(NetoTb3A.2,
#'      interaction.plot(f1, f3, delta,
#'                       xlab = "Concentração",
#'                       ylab = "Sílica Modificada",
#'                       main = "Concentração x Sílica Modificada",
#'                       col = "blue"))
#'
#' with(NetoTb3A.2,
#'      interaction.plot(f2, f3, delta,
#'                       xlab = "PH",
#'                       ylab = "Sílica Modificada",
#'                       main = "PH x Sílica Modificada",
#'                       col = "red"))
#'
NULL
