#' @name NetoTb3A.3
#' @title Tempo de Retenção em Cromatografia Líquida
#' @description Um fatorial foi usado para investigar como o tempo de
#'     retenção de um pico obtido em um cromatógrafo líquido é afetado
#'     pela porcentagem de etanol, temperatura e fluxo de gás.
#' @format Um \code{data.frame} com 8 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{f1}}{Fator 1, temperatura (30 e 50), em grau celsius.}
#'
#' \item{\code{f2}}{Fator 2, porcentagem de etanol (v/v, 60 e 70).}
#'
#' \item{\code{f3}}{Fator 3, fluxo, em mL min\eqn{^{-1}}.}
#'
#' \item{\code{temp}}{Tempo de retenção, em minutos.}
#'
#' }
#' @keywords FAT2K
#' @source NETO el al. (2010), Tabela 3A.3, pág. 149.
#' @examples
#'
#' data(NetoTb3A.3)
#' str(NetoTb3A.3)
#'
#' par(mfrow = c(1,3))
#'
#' with(NetoTb3A.3,
#'      interaction.plot(f1, f2, temp,
#'                       xlab = "Temperatura",
#'                       ylab = "Tempo Médio",
#'                       main = " Temperatura x Etanol",
#'                       col = "green"))
#'
#' with(NetoTb3A.3,
#'      interaction.plot(f1, f3, temp,
#'                       xlab = "Temperatura",
#'                       ylab = "Tempo Médio",
#'                       main = " Temperatura x Fluxo",
#'                       col = "blue"))
#'
#' with(NetoTb3A.3,
#'      interaction.plot(f2, f3, temp,
#'                       xlab = "% de etanol",
#'                       ylab = "Tempo Médio",
#'                       main = "Etanol x Fluxo",
#'                       col = "red"))
#'
NULL
