#' @name NetoTb3A.4
#' @title Separação de Gases por Adsorção
#' @description No desenvolvimento em laboratório de um processo de
#'     enriquecimento de gases por adsorção, usou-se um planejamento
#'     \eqn{2^4} para investigar a influência de quatro fatores na
#'     produtividade do adsorvente.
#' @format Um \code{data.frame} com 16 observações e 5 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{f1}}{Fator 1, pressão de adsorção (1.40 e 2.40 bar).}
#'
#' \item{\code{f2}}{Fator 2, pressão de dessorção (0.05 e 0.20 bar).}
#'
#' \item{\code{f3}}{Fator 3, vazão de alimentação (0.10 e 0.30 m\eqn{^3}
#'     hora\eqn{^{-1}}).}
#'
#' \item{\code{f4}}{Fator 4, tempo de adsorção (8 e 30 s).}
#'
#' \item{\code{p}}{Produtividade do adsorvente (mol kg\eqn{^{-1}})
#'     ciclo\eqn{^{-1}}.}
#'
#' }
#' @keywords FAT2K
#' @source NETO et al. (2010), Tabela 3A.4, pág. 151.
#' @examples
#'
#' library(lattice)
#'
#' data(NetoTb3A.4)
#' str(NetoTb3A.4)
#'
#' xyplot(p ~ f1 | f2,
#'        groups = interaction(f3, f4, sep = ":"),
#'        data = NetoTb3A.4,
#'        type = c("p", "a"),
#'        auto.key = TRUE)
#'
NULL
